@@ -1,10 +1,5 @@
 #!/usr/bin/env python
 
-import sys
-import os
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-
-
 from stringlike import StringLike
 from unittest import main, TestCase
 
@@ -121,11 +116,6 @@ class TestStringLikeMagicMethods(TestCase):
         with self.assertRaises(AttributeError):
             StringMock('').gobbledygook()
 
-    def test_instancecheck(self):
-        self.assertTrue(isinstance(StringMock(''), StringLike))
-        self.assertTrue(isinstance(StringMock(''), str))
-        self.assertTrue(isinstance(StringMock(''), basestring))
-
 
 class TestSomeStringMethods(TestCase):
     def test_capitalize(self):
