@@ -1,10 +1,5 @@
 #!/usr/bin/env python
 
-import sys
-import os
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-
-
 from stringlike.lazy import LazyString, CachedLazyString
 from unittest import main, TestCase
 
